@@ -1,5 +1,5 @@
 package Music::Intervals::Numeric;
-$Music::Intervals::Numeric::VERSION = '0.0706';
+$Music::Intervals::Numeric::VERSION = '0.0707';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Breakdown of numeric musical intervals
@@ -19,15 +19,11 @@ use namespace::clean;
 has notes => ( is => 'ro', default => sub { [] } );
 has size  => ( is => 'ro', default => sub { 3 } );
 
-has _semitones => ( is => 'ro', default => sub { 12 } );
-has _temper    => ( is => 'ro', lazy => 1, default => sub { my $self = shift;
-    $self->_semitones * 100 / log(2) },
-);
-has _ratios => (
+has ratios => (
     is      => 'ro',
     builder => 1,
 );
-sub _build__ratios {
+sub _build_ratios {
   my ($self) = @_;
   no warnings 'once';
   my $ratios = { map {
@@ -36,6 +32,11 @@ sub _build__ratios {
   return $ratios;
 }
 
+has _semitones => ( is => 'ro', default => sub { 12 } );
+has _temper    => ( is => 'ro', lazy => 1, default => sub { my $self = shift;
+    $self->_semitones * 100 / log(2) },
+);
+
 
 sub frequencies {
     my ($self) = @_;
@@ -45,7 +46,7 @@ sub frequencies {
     my $iter = combinations( $self->notes, $self->size );
 
     while (my $c = $iter->next) {
-        $frequencies->{"@$c"} = { map { $_ => $self->_ratios->{$_} } @$c };
+        $frequencies->{"@$c"} = { map { $_ => $self->ratios->{$_} } @$c };
     }
 
     return $frequencies;
@@ -64,7 +65,7 @@ sub intervals {
         $intervals->{"@$c"} = {
             map {
                 $_ => {
-                    $dyads{$_} => $self->_ratios->{ $dyads{$_} }
+                    $dyads{$_} => $self->ratios->{ $dyads{$_} }
                 }
             } keys %dyads
         };
@@ -165,7 +166,7 @@ Music::Intervals::Numeric - Breakdown of numeric musical intervals
 
 =head1 VERSION
 
-version 0.0706
+version 0.0707
 
 =head1 SYNOPSIS
 
@@ -183,6 +184,8 @@ version 0.0706
     $m->prime_factor,
   );
 
+  my interval = $m->ratios->{'5/4'};
+
 =head1 DESCRIPTION
 
 A C<Music::Intervals> object shows the mathematical break-down of musical
@@ -206,6 +209,10 @@ Chord size
 
 Default: 3
 
+=head2 ratios
+
+Musical ratios keyed by interval fractions.
+
 =head1 METHODS
 
 =head2 new
